@@ -12,17 +12,29 @@
 
 /*
  * This function demonstrates how easy it is to extend
- * elektra. We use ksNext() and keyIsBelow() to implement a function
+ * elektra. We use ksGetSize(), ksAtCursor() and keyIsBelow() to implement a function
  * which skips to the next directory. */
-Key * ksNextDir (KeySet * ks)
+Key * ksNextDir (KeySet * ks, elektraCursor startPos)
 {
 	Key * cur;
-	Key * startKey = ksCurrent (ks);
+	Key * startKey = NULL;
+	static elektraCursor lastPos = 0;
 
-	if (!startKey) return (ksNext (ks));
-
-	while ((cur = ksNext (ks)) != 0)
+	if (startPos >= 0)
 	{
+		/* use given start position */
+		lastPos = startPos;
+	}
+
+	if (ksGetSize (ks) > lastPos)
+	{
+		startKey = ksAtCursor (ks, lastPos);
+	}
+
+	/* Check keys */
+	for (lastPos = lastPos + 1; lastPos < ksGetSize (ks); ++lastPos)
+	{
+		cur = ksAtCursor (ks, lastPos);
 		if (!keyIsBelow (startKey, cur)) return cur;
 	}
 
@@ -47,15 +59,17 @@ int main (void)
 		keyNew ("user:/dir5", KEY_END), KS_END);
 
 	printf ("Iterate over all keys:\n");
-	ksRewind (ks);
-	while ((cur = ksNext (ks)) != 0)
+
+	for (elektraCursor it = 0; it < ksGetSize (ks); ++it)
 	{ /* Iterates over all keys and prints their name */
+		cur = ksAtCursor (ks, it);
 		printf ("%s\n", keyName (cur));
 	}
 
 	printf ("\nIterate over all directories:\n");
-	ksRewind (ks);
-	while ((cur = ksNextDir (ks)) != 0)
+
+
+	while ((cur = ksNextDir (ks, -1)) != 0)
 	{ /* Iterates over all keys and prints their name */
 		printf ("%s\n", keyName (cur));
 	}
@@ -63,8 +77,10 @@ int main (void)
 	printf ("\nLookup and then iterate:\n");
 	found = ksLookupByName (ks, "user:/dir2", 0);
 	printf ("Found key %s\n", keyName (found));
-	while ((cur = ksNext (ks)) != 0)
+
+	for (ssize_t pos = ksSearch (ks, found); pos >= 0 && pos < ksGetSize (ks); ++pos)
 	{ /* Iterates over all keys direct below and prints their name */
+		cur = ksAtCursor (ks, pos);
 		if (keyIsDirectlyBelow (found, cur) == 0) break;
 		printf ("%s\n", keyName (cur));
 	}
