@@ -107,14 +107,15 @@ void Plugin::loadInfo ()
 
 	if (!plugin->kdbGet)
 	{
-		throw MissingSymbol ("kdbGet");
+		throw MissingSymbol ("kdbGet", plugin->name);
 	}
 	plugin->kdbGet (plugin, info.getKeySet (), *infoKey);
 }
 
 void Plugin::parse ()
 {
-	Key root (std::string ("system:/elektra/modules/") + spec.getName (), KEY_END);
+	Key root ("system:/elektra/modules/", KEY_END);
+	root.addBaseName (spec.getName ());
 
 	Key k = info.lookup (root);
 	if (!k)
@@ -122,7 +123,7 @@ void Plugin::parse ()
 		throw PluginNoContract ();
 	}
 
-	root.setName (std::string ("system:/elektra/modules/") + spec.getName () + "/exports");
+	root.addBaseName ("exports");
 
 	ssize_t it = info.search (root) + 1;
 	if (it > 0)
@@ -131,11 +132,11 @@ void Plugin::parse ()
 		{
 			k = info.at (it);
 			if (!k.isBelow (root)) break;
-			symbols[k.getBaseName ()] = (*k.getFunc ());
+			symbols[k.getName ().substr (root.getName ().length () + 1)] = (*k.getFunc ());
 		}
 	}
 
-	root.setName (std::string ("system:/elektra/modules/") + spec.getName () + "/infos");
+	root.setBaseName ("infos");
 
 	it = info.search (root) + 1;
 	if (it > 0)
@@ -144,7 +145,7 @@ void Plugin::parse ()
 		{
 			k = info.at (it);
 			if (!k.isBelow (root)) break;
-			infos[k.getBaseName ()] = k.getString ();
+			infos[k.getName ().substr (root.getName ().length () + 1)] = k.getString ();
 		}
 	}
 	else
@@ -205,32 +206,41 @@ void Plugin::check (vector<string> & warnings)
 			warnings.push_back ("placements are empty");
 		}
 
-		std::vector<std::string> pp;
-		pp.push_back ("prerollback");
-		pp.push_back ("rollback");
-		pp.push_back ("postrollback");
-		pp.push_back ("getresolver");
-		pp.push_back ("pregetcache");
-		pp.push_back ("pregetstorage");
-		pp.push_back ("getstorage");
-		pp.push_back ("procgetstorage");
-		pp.push_back ("postgetstorage");
-		pp.push_back ("postgetcache");
-		pp.push_back ("setresolver");
-		pp.push_back ("postgetcleanup");
-		pp.push_back ("presetstorage");
-		pp.push_back ("setstorage");
-		pp.push_back ("presetcleanup");
-		pp.push_back ("precommit");
-		pp.push_back ("commit");
-		pp.push_back ("postcommit");
-		istringstream is (placements);
-		std::string placement;
-		while (is >> placement)
+		if (placements == "backend" || placements == "hook")
 		{
-			if (std::find (pp.begin (), pp.end (), placement) == pp.end ())
+			// accepted
+			// TODO (flo91): add checks in new mount tooling
+		}
+		else
+		{
+			std::vector<std::string> pp;
+			pp.push_back ("hook");
+			pp.push_back ("prerollback");
+			pp.push_back ("rollback");
+			pp.push_back ("postrollback");
+			pp.push_back ("getresolver");
+			pp.push_back ("pregetcache");
+			pp.push_back ("pregetstorage");
+			pp.push_back ("getstorage");
+			pp.push_back ("procgetstorage");
+			pp.push_back ("postgetstorage");
+			pp.push_back ("postgetcache");
+			pp.push_back ("setresolver");
+			pp.push_back ("postgetcleanup");
+			pp.push_back ("presetstorage");
+			pp.push_back ("setstorage");
+			pp.push_back ("presetcleanup");
+			pp.push_back ("precommit");
+			pp.push_back ("commit");
+			pp.push_back ("postcommit");
+			istringstream is (placements);
+			std::string placement;
+			while (is >> placement)
 			{
-				warnings.push_back ("not supported placement " + placement + " found");
+				if (std::find (pp.begin (), pp.end (), placement) == pp.end ())
+				{
+					warnings.push_back ("not supported placement " + placement + " found");
+				}
 			}
 		}
 	}
@@ -340,7 +350,7 @@ void Plugin::check (vector<string> & warnings)
 	}
 }
 
-ckdb::Plugin * Plugin::operator-> ()
+ckdb::Plugin * Plugin::operator->()
 {
 	return plugin;
 }
@@ -396,7 +406,7 @@ int Plugin::open (kdb::Key & errorKey)
 {
 	if (!plugin->kdbOpen)
 	{
-		throw MissingSymbol ("kdbOpen");
+		throw MissingSymbol ("kdbOpen", plugin->name);
 	}
 
 	return plugin->kdbOpen (plugin, errorKey.getKey ());
@@ -406,7 +416,7 @@ int Plugin::close (kdb::Key & errorKey)
 {
 	if (!plugin->kdbClose)
 	{
-		throw MissingSymbol ("kdbClose");
+		throw MissingSymbol ("kdbClose", plugin->name);
 	}
 
 	return plugin->kdbClose (plugin, errorKey.getKey ());
@@ -420,7 +430,7 @@ int Plugin::get (kdb::KeySet & ks, kdb::Key & parentKey)
 {
 	if (!plugin->kdbGet)
 	{
-		throw MissingSymbol ("kdbGet");
+		throw MissingSymbol ("kdbGet", plugin->name);
 	}
 
 	return plugin->kdbGet (plugin, ks.getKeySet (), parentKey.getKey ());
@@ -434,7 +444,7 @@ int Plugin::set (kdb::KeySet & ks, kdb::Key & parentKey)
 {
 	if (!plugin->kdbSet)
 	{
-		throw MissingSymbol ("kdbSet");
+		throw MissingSymbol ("kdbSet", plugin->name);
 	}
 
 	return plugin->kdbSet (plugin, ks.getKeySet (), parentKey.getKey ());
@@ -444,7 +454,7 @@ int Plugin::commit (kdb::KeySet & ks, kdb::Key & parentKey)
 {
 	if (!plugin->kdbCommit)
 	{
-		throw MissingSymbol ("kdbCommit");
+		throw MissingSymbol ("kdbCommit", plugin->name);
 	}
 
 	return plugin->kdbCommit (plugin, ks.getKeySet (), parentKey.getKey ());
@@ -454,14 +464,14 @@ int Plugin::error (kdb::KeySet & ks, kdb::Key & parentKey)
 {
 	if (!plugin->kdbError)
 	{
-		throw MissingSymbol ("kdbError");
+		throw MissingSymbol ("kdbError", plugin->name);
 	}
 
 	return plugin->kdbError (plugin, ks.getKeySet (), parentKey.getKey ());
 }
 
 
-std::string Plugin::name () // TODO: rename + use internally
+std::string Plugin::name ()
 {
 	return spec.getName ();
 }
@@ -476,12 +486,8 @@ std::string Plugin::refname ()
 	if (firstRef)
 	{
 		firstRef = false;
-		return std::string ("#") + spec.getName () + "#" + spec.getRefName () + "#";
-	}
-	else
-	{
-		return std::string ("#") + spec.getRefName ();
 	}
+	return spec.getRefName ();
 }
 } // namespace tools
 } // namespace kdb
