@@ -18,27 +18,27 @@
 #include <yajl/yajl_parse.h>
 
 
+static elektraCursor itKs;
+
 static void elektraYajlSetArrayLength (KeySet * ks, Key * current)
 {
 	// Update array length in array key
-	elektraCursor cursor = ksGetCursor (ks);
 	Key * arrayKey = keyNew (keyName (current), KEY_END);
 	keySetBaseName (arrayKey, 0);
 	Key * foundKey = ksLookup (ks, arrayKey, 0);
 	keySetMeta (foundKey, "array", keyBaseName (current));
 	keyDel (arrayKey);
-	ksSetCursor (ks, cursor);
 }
 
 /**
- @retval 0 if ksCurrent does not hold an array entry
+ @retval 0 if ksAtCursor(ks, it) does not hold an array entry
  @retval 1 if the array entry will be used because its the first
  @retval 2 if a new array entry was created
  @retval -1 error in snprintf
  */
 static int elektraYajlIncrementArrayEntry (KeySet * ks)
 {
-	Key * current = ksCurrent (ks);
+	Key * current = ksAtCursor (ks, itKs);
 	const char * baseName = keyBaseName (current);
 	const char * meta = keyString (keyGetMeta (current, "array"));
 	if (!strcmp (meta, "empty"))
@@ -46,7 +46,7 @@ static int elektraYajlIncrementArrayEntry (KeySet * ks)
 		current = keyNew (keyName (current), KEY_END);
 		keyAddName (current, "#0");
 		ksAppendKey (ks, current);
-
+		itKs = ksSearch (ks, current);
 		elektraYajlSetArrayLength (ks, current);
 
 		return 1;
@@ -57,7 +57,7 @@ static int elektraYajlIncrementArrayEntry (KeySet * ks)
 		current = keyNew (keyName (current), KEY_END);
 		elektraArrayIncName (current);
 		ksAppendKey (ks, current);
-
+		itKs = ksSearch (ks, current);
 		elektraYajlSetArrayLength (ks, current);
 
 		return 2;
@@ -74,7 +74,7 @@ static int elektraYajlParseNull (void * ctx)
 	KeySet * ks = (KeySet *) ctx;
 	elektraYajlIncrementArrayEntry (ks);
 
-	Key * current = ksCurrent (ks);
+	Key * current = ksAtCursor (ks, itKs);
 
 	keySetBinary (current, NULL, 0);
 
@@ -88,7 +88,7 @@ static int elektraYajlParseBoolean (void * ctx, int boolean)
 	KeySet * ks = (KeySet *) ctx;
 	elektraYajlIncrementArrayEntry (ks);
 
-	Key * current = ksCurrent (ks);
+	Key * current = ksAtCursor (ks, itKs);
 
 	if (boolean == 1)
 	{
@@ -110,7 +110,7 @@ static int elektraYajlParseNumber (void * ctx, const char * stringVal, yajl_size
 	KeySet * ks = (KeySet *) ctx;
 	elektraYajlIncrementArrayEntry (ks);
 
-	Key * current = ksCurrent (ks);
+	Key * current = ksAtCursor (ks, itKs);
 
 	unsigned char delim = stringVal[stringLen];
 	char * stringValue = (char *) stringVal;
@@ -132,7 +132,7 @@ static int elektraYajlParseString (void * ctx, const unsigned char * stringVal,
 	KeySet * ks = (KeySet *) ctx;
 	elektraYajlIncrementArrayEntry (ks);
 
-	Key * current = ksCurrent (ks);
+	Key * current = ksAtCursor (ks, itKs);
 
 	unsigned char delim = stringVal[stringLen];
 	char * stringValue = (char *) stringVal;
@@ -152,7 +152,7 @@ static int elektraYajlParseMapKey (void * ctx, const unsigned char * stringVal,
 	KeySet * ks = (KeySet *) ctx;
 	elektraYajlIncrementArrayEntry (ks);
 
-	Key * currentKey = keyNew (keyName (ksCurrent (ks)), KEY_END);
+	Key * currentKey = keyNew (keyName (ksAtCursor (ks, itKs)), KEY_END);
 	keySetString (currentKey, 0);
 
 	unsigned char delim = stringVal[stringLen];
@@ -164,6 +164,7 @@ static int elektraYajlParseMapKey (void * ctx, const unsigned char * stringVal,
 	{
 		// remove old key
 		keyDel (ksLookup (ks, currentKey, KDB_O_POP));
+		itKs = 0; // current key was popped from KeySet
 		// now we know the name of the object
 		keySetBaseName (currentKey, stringValue);
 	}
@@ -173,6 +174,7 @@ static int elektraYajlParseMapKey (void * ctx, const unsigned char * stringVal,
 		keySetBaseName (currentKey, stringValue);
 	}
 	ksAppendKey (ks, currentKey);
+	itKs = ksSearch (ks, currentKey);
 
 	// restore old character in buffer
 	stringValue[stringLen] = delim;
@@ -185,12 +187,13 @@ static int elektraYajlParseStartMap (void * ctx)
 	KeySet * ks = (KeySet *) ctx;
 	elektraYajlIncrementArrayEntry (ks);
 
-	Key * currentKey = ksCurrent (ks);
+	Key * currentKey = ksAtCursor (ks, itKs);
 
 	Key * newKey = keyNew (keyName (currentKey), KEY_END);
 	// add a pseudo element for empty map
 	keyAddBaseName (newKey, "___empty_map");
 	ksAppendKey (ks, newKey);
+	itKs = ksSearch (ks, newKey);
 
 	ELEKTRA_LOG_DEBUG ("with new key %s", keyName (newKey));
 
@@ -200,7 +203,7 @@ static int elektraYajlParseStartMap (void * ctx)
 static int elektraYajlParseEnd (void * ctx)
 {
 	KeySet * ks = (KeySet *) ctx;
-	Key * currentKey = ksCurrent (ks);
+	Key * currentKey = ksAtCursor (ks, itKs);
 
 	const char * meta = keyString (keyGetMeta (currentKey, "array"));
 	// If array is still empty by the time we reach the end, replace with ""
@@ -213,20 +216,18 @@ static int elektraYajlParseEnd (void * ctx)
 	Key * lookupKey = keyNew (keyName (currentKey), KEY_END);
 	keySetBaseName (lookupKey, 0); // remove current baseName
 
-	// lets point current to the correct place
-	Key * foundKey = ksLookup (ks, lookupKey, 0);
+	// lets move iterator to the correct place
+	itKs = ksSearch (ks, lookupKey);
 
 #ifdef HAVE_LOGGER
-	if (foundKey)
+	if (itKs >= 0)
 	{
-		ELEKTRA_LOG_DEBUG ("%s", keyName (foundKey));
+		ELEKTRA_LOG_DEBUG ("Iterator position: %zd", itKs);
 	}
 	else
 	{
-		ELEKTRA_LOG_DEBUG ("did not find key %s", keyName (lookupKey));
+		ELEKTRA_LOG_DEBUG ("Did not find key %s", keyName (lookupKey));
 	}
-#else
-	(void) foundKey; // foundKey is not used, but lookup is needed
 #endif
 
 	keyDel (lookupKey);
@@ -239,11 +240,12 @@ static int elektraYajlParseStartArray (void * ctx)
 	KeySet * ks = (KeySet *) ctx;
 	elektraYajlIncrementArrayEntry (ks);
 
-	Key * currentKey = ksCurrent (ks);
+	Key * currentKey = ksAtCursor (ks, itKs);
 
 	Key * newKey = keyNew (keyName (currentKey), KEY_END);
 	keySetMeta (newKey, "array", "empty");
 	ksAppendKey (ks, newKey);
+	itKs = ksSearch (ks, newKey);
 
 	ELEKTRA_LOG_DEBUG ("with new key %s", keyName (newKey));
 
@@ -257,26 +259,27 @@ static int elektraYajlParseStartArray (void * ctx)
  */
 static void elektraYajlParseSuppressNonLeafKeys (KeySet * returned)
 {
-	ksRewind (returned);
-	Key * cur = ksNext (returned);
+	elektraCursor it = 0;
+	Key * cur = ksAtCursor (returned, it);
+
 	while (cur != NULL)
 	{
-		elektraCursor cursor = ksGetCursor (returned);
+		Key * next = ksAtCursor (returned, ++it);
+		if (next == NULL) break;
 
-		if (ksNext (returned) == NULL) break;
 
-		Key * peekDup = keyDup (ksCurrent (returned), KEY_CP_ALL);
+		Key * peekDup = keyDup (next, KEY_CP_ALL);
 		keySetBaseName (peekDup, 0);
 
 		if (!strcmp (keyName (peekDup), keyName (cur)))
 		{
-			const char * baseName = keyBaseName (ksCurrent (returned));
+			const char * baseName = keyBaseName (next);
 			// TODO: Add test for empty array check
 			if (strcmp (baseName, "#0"))
 			{
 				ELEKTRA_LOG_DEBUG ("Removing non-leaf key %s", keyName (cur));
 				keyDel (ksLookup (returned, cur, KDB_O_POP));
-				ksSetCursor (returned, cursor);
+				it--;
 			}
 			else
 			{
@@ -286,7 +289,7 @@ static void elektraYajlParseSuppressNonLeafKeys (KeySet * returned)
 		}
 
 		keyDel (peekDup);
-		cur = ksCurrent (returned);
+		cur = ksAtCursor (returned, it);
 	}
 }
 
@@ -312,15 +315,15 @@ static void elektraYajlParseSuppressEmptyMap (KeySet * returned, Key * parentKey
 		}
 		else
 		{
-			ksRewind (returned);
 			Key * cur;
-			while ((cur = ksNext (returned)) != 0)
+
+			for (elektraCursor it = 0; it < ksGetSize (returned); ++it)
 			{
+				cur = ksAtCursor (returned, it);
 				ELEKTRA_LOG_DEBUG ("key %s has value %s", keyName (cur), keyString (cur));
 			}
 
 			ELEKTRA_LOG_DEBUG ("did not find %s", keyName (lookupKey));
-			ksRewind (returned);
 		}
 #endif
 		if (toRemove)
@@ -389,6 +392,8 @@ int elektraYajlGet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned, Key * par
 		return -1;
 	}
 
+	/* external iteration of the keyset */
+	itKs = 0;
 	while (!done)
 	{
 		yajl_size_type rd = fread ((void *) fileData, 1, sizeof (fileData) - 1, fileHandle);
