@@ -73,7 +73,7 @@ static inline std::string getArgDescription (const kdb::Key & key, kdb_long_long
 	auto indexStr = std::to_string (index);
 	auto metaName = "gen/arg/description/#" + std::string (indexStr.length () - 1, '_') + indexStr;
 	return key.hasMeta (metaName) ? key.getMeta<std::string> (metaName) :
-					      "Replaces occurrence no. " + indexStr + " of " + kind + " in the keyname.";
+					"Replaces occurrence no. " + indexStr + " of " + kind + " in the keyname.";
 }
 
 static void getKeyArgs (const kdb::Key & key, const size_t parentKeyParts, kainjow::mustache::list & args, std::string & fmtString)
@@ -633,7 +633,8 @@ kainjow::mustache::data HighlevelGenTemplate::getTemplateData (const std::string
 		kdb::printError (std::cerr, parentKeyMaybeWithErrors, false, false);
 		throw CommandAbortException ("Error during calculation of specification token.");
 	}
-	contract.append (kdb::Key ("system:/elektra/contract/highlevel/check/spec/token", KEY_VALUE, token, KEY_END));
+	// FIXME [new_backend]: token calculation broken
+	// contract.append (kdb::Key ("system:/elektra/contract/highlevel/check/spec/token", KEY_VALUE, token, KEY_END));
 
 
 	data["keys_count"] = std::to_string (keys.size ());
