@@ -30,6 +30,7 @@
 #include <regex.h>
 
 #include <kdbinternal.h>
+#include <kdbprivate.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -353,63 +354,6 @@ void output_plugin (Plugin * plugin)
 	output_keyset (plugin->config);
 }
 
-void output_backend (Backend * backend)
-{
-	if (!backend) return;
-
-	printf ("us: %zd, ss: %zd\n", backend->usersize, backend->systemsize);
-	output_key (backend->mountpoint);
-}
-
-void output_trie (Trie * trie)
-{
-	int i;
-	for (i = 0; i < KDB_MAX_UCHAR; ++i)
-	{
-		if (trie->value[i])
-		{
-			printf ("output_trie: %p, mp: %s %s [%d]\n", (void *) trie->value[i], keyName (trie->value[i]->mountpoint),
-				keyString (trie->value[i]->mountpoint), i);
-		}
-		if (trie->children[i]) output_trie (trie->children[i]);
-	}
-	if (trie->empty_value)
-	{
-		printf ("empty_value: %p, mp: %s %s\n", (void *) trie->empty_value, keyName (trie->empty_value->mountpoint),
-			keyString (trie->empty_value->mountpoint));
-	}
-}
-
-void output_split (Split * split)
-{
-	printf ("Split - size: %zu, alloc: %zu\n", split->size, split->alloc);
-	for (size_t i = 0; i < split->size; ++i)
-	{
-		if (split->handles[i])
-		{
-			printf ("split #%zu size: %zd, handle: %p, sync: %d, parent: %s (%s), spec: %zd, dir: %zd, user: %zd, system: "
-				"%zd\n",
-				i, ksGetSize (split->keysets[i]), (void *) split->handles[i], split->syncbits[i],
-				keyName (split->parents[i]), keyString (split->parents[i]), split->handles[i]->specsize,
-				split->handles[i]->dirsize, split->handles[i]->usersize, split->handles[i]->systemsize);
-		}
-		else
-		{
-			printf ("split #%zu, size: %zd, default split, sync: %d\n", i, ksGetSize (split->keysets[i]), split->syncbits[i]);
-		}
-	}
-}
-
-void generate_split (Split * split)
-{
-	printf ("succeed_if (split->size == %zu, \"size of split not correct\");\n", split->size);
-	for (size_t i = 0; i < split->size; ++i)
-	{
-		printf ("succeed_if (split->syncbits[%zu]== %d, \"size of split not correct\");\n", i, split->syncbits[i]);
-		printf ("succeed_if (ksGetSize(split->keysets[%zu]) == %zd, \"wrong size\");\n", i, ksGetSize (split->keysets[i]));
-	}
-}
-
 /**
  * @brief Output warnings if present
  *
