@@ -1,3 +1,5 @@
+#!/bin/sh
+
 @INCLUDE_COMMON@
 
 echo
@@ -41,68 +43,68 @@ for PLUGIN in $PLUGINS; do
 	echo
 	echo "-- Testing $PLUGIN"
 
-	check_remaining_files $FILE
+	check_remaining_files "$FILE"
 
-	"$KDB" mount $FILE $MOUNTPOINT $MOUNT_PLUGIN 1> /dev/null
+	"$KDB" mount "$FILE" "$MOUNTPOINT" "$MOUNT_PLUGIN" 1> /dev/null
 	exit_if_fail "could not mount $FILE at $MOUNTPOINT using $MOUNT_PLUGIN"
 
 	cleanup() {
-		"$KDB" umount $MOUNTPOINT > /dev/null
+		"$KDB" umount "$MOUNTPOINT" > /dev/null
 		succeed_if "could not umount $MOUNTPOINT"
-		rm -f $USER_FOLDER/$FILE
-		rm -f $SYSTEM_FOLDER/$FILE
+		rm -f "$USER_FOLDER"/"$FILE"
+		rm -f "$SYSTEM_FOLDER"/"$FILE"
 
-		USER_REMAINING="$(find $USER_FOLDER -maxdepth 1 -name $FILE'*' -print -exec rm {} +)"
+		USER_REMAINING="$(find "$USER_FOLDER" -maxdepth 1 -name "$FILE"'*' -print -exec rm {} +)"
 		test -z "$USER_REMAINING"
 		succeed_if "found remaining files $USER_REMAINING in $USER_FOLDER"
 
-		SYSTEM_REMAINING="$(find $SYSTEM_FOLDER -maxdepth 1 -name $FILE'*' -print -exec rm {} +)"
+		SYSTEM_REMAINING="$(find "$SYSTEM_FOLDER" -maxdepth 1 -name "$FILE"'*' -print -exec rm {} +)"
 		test -z "$SYSTEM_REMAINING"
 		succeed_if "found remaining files $SYSTEM_REMAINING in $SYSTEM_FOLDER"
 	}
 
 	for ROOT in $ROOTS; do
 		#echo "do preparation for $PLUGIN in $ROOT"
-		"$KDB" set $ROOT "root" 1> /dev/null
+		"$KDB" set "$ROOT" "root" 1> /dev/null
 		succeed_if "could not set root"
 
-		[ "x$("$KDB" sget $ROOT/value defvalue 2> /dev/null)" = "xdefvalue" ]
+		[ "x$("$KDB" sget "$ROOT"/value defvalue 2> /dev/null)" = "xdefvalue" ]
 		succeed_if "Did not get default value"
 
 		"$KDB" set "$ROOT/value" "$VALUE" 1> /dev/null
 		succeed_if "could not set value"
 
-		[ "x$("$KDB" get $ROOT/value 2> /dev/null)" = "x$VALUE" ]
+		[ "x$("$KDB" get "$ROOT"/value 2> /dev/null)" = "x$VALUE" ]
 		succeed_if "cant get $ROOT/value"
 
-		[ "x$("$KDB" sget $ROOT/value default 2> /dev/null)" = "x$VALUE" ]
+		[ "x$("$KDB" sget "$ROOT"/value default 2> /dev/null)" = "x$VALUE" ]
 		succeed_if "cant shell get $ROOT/value"
 
 		echo "testing ls command"
 
-		[ "x$("$KDB" ls $ROOT/value 2> /dev/null)" = "x$ROOT/value" ]
+		[ "x$("$KDB" ls "$ROOT"/value 2> /dev/null)" = "x$ROOT/value" ]
 		succeed_if "cant ls $ROOT (may mean that $ROOT folder is not clean)"
 
 		echo "testing rm command"
 
-		"$KDB" rm $ROOT/value 1> /dev/null
+		"$KDB" rm "$ROOT"/value 1> /dev/null
 		succeed_if "could not remove user:/test/value"
 
-		"$KDB" get $ROOT/value 1> /dev/null
+		"$KDB" get "$ROOT"/value 1> /dev/null
 		[ $? != "0" ]
 		succeed_if "got removed key $ROOT/value"
 
-		"$KDB" rm $ROOT 1> /dev/null
+		"$KDB" rm "$ROOT" 1> /dev/null
 		succeed_if "could not remove user:/test/value"
 
-		[ "x$("$KDB" sget $ROOT/value value 2> /dev/null)" = "xvalue" ]
+		[ "x$("$KDB" sget "$ROOT"/value value 2> /dev/null)" = "xvalue" ]
 		succeed_if "Did not get default value after remove"
 
-		"$KDB" get $ROOT/value 1> /dev/null
+		"$KDB" get "$ROOT"/value 1> /dev/null
 		[ $? != "0" ]
 		succeed_if "got removed key $ROOT"
 
-		check_set_rm $ROOT/value other_value
+		check_set_rm "$ROOT"/value other_value
 
 		echo "testing array"
 
@@ -110,7 +112,7 @@ for PLUGIN in $PLUGINS; do
 		"$KDB" set "$KEY" "$VALUE" 1> /dev/null
 		succeed_if "could not set key $KEY"
 
-		[ "x$("$KDB" get $KEY)" = "x$VALUE" ]
+		[ "x$("$KDB" get "$KEY")" = "x$VALUE" ]
 		succeed_if "$KEY is not $VALUE"
 
 		i=0
@@ -123,10 +125,10 @@ for PLUGIN in $PLUGINS; do
 			succeed_if "could not set key $ROOT/hello/a/array/#0"
 
 			if [ "$i" -eq 0 ] && [ "x$PLUGIN" = "xini" ]; then
-				[ "x$("$KDB" get $ROOT/hello/a/array)" = "x$VALUE" ]
+				[ "x$("$KDB" get "$ROOT"/hello/a/array)" = "x$VALUE" ]
 				succeed_if "$KEY is not $VALUE"
 			else
-				[ "x$("$KDB" get $KEY)" = "x$VALUE" ]
+				[ "x$("$KDB" get "$KEY")" = "x$VALUE" ]
 				succeed_if "$KEY is not $VALUE"
 			fi
 			i=$((i + 1))
@@ -135,10 +137,10 @@ for PLUGIN in $PLUGINS; do
 		"$KDB" rm -r "$ROOT"
 		succeed_if "could not remove all keys"
 
-		test ! -f $USER_FOLDER/$FILE
+		test ! -f "$USER_FOLDER"/"$FILE"
 		succeed_if "user file was not removed"
 
-		test ! -f $SYSTEM_FOLDER/$FILE
+		test ! -f "$SYSTEM_FOLDER"/"$FILE"
 		succeed_if "system file was not removed"
 	done
 
