@@ -1,3 +1,5 @@
+#!/bin/sh
+
 @INCLUDE_COMMON@
 
 echo
@@ -27,7 +29,7 @@ else
 fi
 
 do_race_test() {
-	RES=$($RACE $*)
+	RES=$($RACE "$@")
 	succeed_if "$RACE $* did not run successfully with error $?"
 
 	WHERE=user:/test/race/keys
