@@ -1,16 +1,23 @@
+#!/bin/sh
+
 @INCLUDE_COMMON@
 
 echo
 echo ELEKTRA CHECK EXTERNAL EXAMPLE
 echo
 
-if command -v pkg-config; then
-	if ! pkg-config elektra; then
-		echo "Elektra not installed, will skip"
+if command -v realpath; then
+	if command -v pkg-config; then
+		if ! pkg-config elektra; then
+			echo "Elektra not installed, will skip"
+			exit 0
+		fi
+	else
+		echo "pkg-config not installed, will skip"
 		exit 0
 	fi
 else
-	echo "pkg-config not installed, will skip"
+	echo "realpath is not installed, will skip"
 	exit 0
 fi
 
@@ -47,12 +54,12 @@ do_tests() {
 
 echo "Testing build with cmake"
 
-cd "$EXTERNAL_FOLDER"
+cd "$EXTERNAL_FOLDER" || exit
 mkdir build
-cd build
+cd build || exit
 
 # manually set Elektra_DIR and KDB to support non-standard install locations
-cmake ../cmake -DElektra_DIR:PATH="$(realpath $(dirname $0)/../../scripts/cmake/Elektra)"
+cmake ../cmake -DElektra_DIR:PATH="$(realpath $(dirname "$0")/../../scripts/cmake/Elektra)"
 succeed_if "could not run cmake"
 
 cmake --build .
@@ -66,7 +73,7 @@ rm -r build
 
 echo "Testing build with pkgconfig"
 
-cd "$EXTERNAL_FOLDER/pkgconfig"
+cd "$EXTERNAL_FOLDER/pkgconfig" || exit
 make
 succeed_if "could not build pkgconfig project"
 
