@@ -1,3 +1,5 @@
+#!/bin/sh
+
 @INCLUDE_COMMON@
 
 set -f
@@ -73,7 +75,7 @@ execute() {
 
 	if [ -n "$RETCMP" ]; then
 		executedTests=$((executedTests + 1))
-		if ! printf '%s' "$RETVAL" | grep -Ewq $RETCMP; then
+		if ! printf '%s' "$RETVAL" | grep -Ewq "$RETCMP"; then
 			printerr '\nERROR - RET:\nReturn value “%s” does not match “%s”\n\n' "$RETVAL" "$RETCMP"
 			printf '=== FAILED return value does not match expected pattern %s\n' "$RETCMP" >> "$OutFile"
 			numberErrors=$((numberErrors + 1))
@@ -130,9 +132,10 @@ execute() {
 	# = WARNINGS =
 	# ============
 
-	WARNINGS=$(printf '%s' "$STDERR" | sed -nE 's/.*Warning (number: |\(#)([0-9]+).*/\2/p' | tr '\n' ',' | sed 's/.$//')
+	WARNINGS=$(printf '%s' "$STDERR" | sed -nE 's/.*warning (C[A-Z0-9]+):/\1/p' | tr '\n' ',' | sed 's/.$//')
 
 	[ -n "$WARNINGS" ] && printf 'WARNINGS: %s\n' "$WARNINGS" >> "$OutFile"
+
 	if [ -n "$WARNINGSCMP" ]; then
 		executedTests=$((executedTests + 1))
 		if ! printf '%s' "$WARNINGS" | replace_newline_return | grep -Eq -- "$WARNINGSCMP"; then
@@ -178,7 +181,7 @@ run_script() {
 		case "$cmd" in
 		Mountpoint:)
 			Mountpoint=$(second "$line")
-			MountpointRoot=$(printf "$Mountpoint" | sed -E 's~(/?[^/]+).*~\1~')
+			MountpointRoot=$(printf "$Mountpoint" | sed -E 's~(/?[^/]+).*~\1/~')
 			;;
 		File:)
 			DBFile=$(second "$line")
@@ -276,6 +279,12 @@ if [ "$#" -lt '1' ] || [ "$#" -gt '2' ]; then
 	exit 0
 fi
 
+if [ ! -f "$FILE" ]; then
+	printf 'File not found: %s' "$FILE"
+	rm "$OutFile"
+	exit 1
+fi
+
 BACKUP=1
 
 EXPORT_DIR="$(mktempdir_elektra)"
